/*==============================================================================


       The Path to Effects, example code showing how to use the Path API
       calls under Builder. Code written by David Pankhurst (www.pankhurst.com)


==============================================================================*/
#include <vcl.h>
#pragma hdrstop

#include "Unit1.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TForm1 *Form1;
//---------------------------------------------------------------------------
__fastcall TForm1::TForm1(TComponent* Owner)
        : TForm(Owner)
{
  // use some non-standard settings to show the effects in action
  Canvas->Pen->Width=3;
  Canvas->Pen->Color=clLime;
  Canvas->Brush->Color=clFuchsia;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button1Click(TObject *Sender)
{
  // outline text
  Repaint(); // clean up old display
  // sample settings
  int x=0, y=0;
  const char *text="Sample Text";
  // begin path recording - in this case, just one string of text
  BeginPath(Canvas->Handle);
  // prevent the text box's outline from being added to the path
  SetBkMode(Canvas->Handle,TRANSPARENT);
  Canvas->TextOut(x,y,text);
  EndPath(Canvas->Handle);
  // now the path can be manipulated - in this case, simple outlining
  StrokePath(Canvas->Handle);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button2Click(TObject *Sender)
{
  // filled/outlined text
  Repaint(); // clean up old display
  // sample settings
  int x=0, y=0;
  const char *text="Sample Text";
  // begin path recording - in this case, just one string of text
  BeginPath(Canvas->Handle);
  // prevent the text box's outline from being added to the path
  SetBkMode(Canvas->Handle,TRANSPARENT);
  Canvas->TextOut(x,y,text);
  EndPath(Canvas->Handle);
  // now the path can be manipulated by outlining and filling
  StrokeAndFillPath(Canvas->Handle); // do fill and outline together (can't do seperate as each destroys the path)
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button3Click(TObject *Sender)
{
  // draw clip window
  Repaint(); // clean up old display
  // sample settings
  int x=0, y=0;
  const char *text="Sample Text";
  // begin path recording - in this case, just one string of text
  BeginPath(Canvas->Handle);
  // prevent the text box's outline from being added to the path
  SetBkMode(Canvas->Handle,TRANSPARENT);
  Canvas->TextOut(x,y,text);
  EndPath(Canvas->Handle);
  // now the path can be used as clipping region - we draw a grid of lines on
  // the whole screen, but only the drawing within the path will appear
  SelectClipPath(Canvas->Handle,RGN_COPY);
  int i=0;
  for (i=0;i<Width;i+=7)
  {
    Canvas->MoveTo(i,0);
    Canvas->LineTo(i,Height);
  }
  for (i=0;i<Height;i+=7)
  {
    Canvas->MoveTo(0,i);
    Canvas->LineTo(Width,i);
  }
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button4Click(TObject *Sender)
{
  // text-shaped window
  Repaint(); // clean up old display
  // sample settings
  int x=0, y=0;
  const char *text="Sample Text";
  // begin path recording - in this case, just one string of text
  BeginPath(Canvas->Handle);
  // prevent the text box's outline from being added to the path
  SetBkMode(Canvas->Handle,TRANSPARENT);
  Canvas->TextOut(x,y,text);
  EndPath(Canvas->Handle);
  // now the path can be manipulated - in this case, turn into window outline
  HRGN region=PathToRegion(Canvas->Handle);
  ::SetWindowRgn(Handle,region,true);
}
//---------------------------------------------------------------------------

